@@ -38,6 +38,7 @@ import unittest
 import unittest.mock
 
 import respx
+from pymongo import MongoClient
 from pymongo_auth_aws.auth import AwsCredential
 
 from pymongocrypt.asynchronous.auto_encrypter import AsyncAutoEncrypter
@@ -143,6 +144,11 @@ class TestMongoCryptOptions(unittest.TestCase):
         )
         self.assertEqual(opts.encrypted_fields_map, encrypted_fields_map)
         self.assertTrue(opts.bypass_query_analysis)
+        for expiration in [0, 1, 1000000]:
+            opts = MongoCryptOptions(
+                valid[0][0], schema_map, key_expiration_ms=expiration
+            )
+            self.assertEqual(opts.key_expiration_ms, expiration)
 
     def test_mongocrypt_options_validation(self):
         with self.assertRaisesRegex(
@@ -192,6 +198,12 @@ class TestMongoCryptOptions(unittest.TestCase):
             TypeError, "encrypted_fields_map must be bytes or None"
         ):
             MongoCryptOptions(valid_kms, encrypted_fields_map={})
+        with self.assertRaisesRegex(TypeError, "key_expiration_ms must be int or None"):
+            MongoCryptOptions(valid_kms, key_expiration_ms="123")
+        with self.assertRaisesRegex(
+            ValueError, "key_expiration_ms must be >=0 or None"
+        ):
+            MongoCryptOptions(valid_kms, key_expiration_ms=-1)
 
 
 class TestMongoCrypt(unittest.TestCase):
@@ -507,6 +519,8 @@ class TestMongoCryptCallback(unittest.TestCase):
         os.getenv("TEST_CRYPT_SHARED"), "this test requires TEST_CRYPT_SHARED=1"
     )
     def test_crypt_shared(self):
+        if sys.platform == "darwin":
+            raise unittest.SkipTest("Skipping due to SERVER-101020")
         kms_providers = {
             "aws": {"accessKeyId": "example", "secretAccessKey": "example"},
             "local": {"key": b"\x00" * 96},
@@ -638,6 +652,8 @@ if sys.version_info >= (3, 8, 0):  # noqa: UP036
             os.getenv("TEST_CRYPT_SHARED"), "this test requires TEST_CRYPT_SHARED=1"
         )
         async def test_crypt_shared(self):
+            if sys.platform == "darwin":
+                raise unittest.SkipTest("Skipping due to SERVER-101020")
             kms_providers = {
                 "aws": {"accessKeyId": "example", "secretAccessKey": "example"},
                 "local": {"key": b"\x00" * 96},
@@ -998,6 +1014,30 @@ if sys.version_info >= (3, 8, 0):  # noqa: UP036
                 encrypted_val, adjust_range_counter(encrypted_val, expected)
             )
 
+        async def test_text_query(self):
+            key_path = "keys/ABCDEFAB123498761234123456789012-local-document.json"
+            key_id = json_data(key_path)["_id"]
+            encrypter = AsyncExplicitEncrypter(
+                MockAsyncCallback(
+                    key_docs=[bson_data(key_path)], kms_reply=http_data("kms-reply.txt")
+                ),
+                self.mongo_crypt_opts(),
+            )
+            self.addCleanup(encrypter.close)
+
+            text_opts = bson_data("fle2-text-search/textopts.json")
+            expected = bson_data("fle2-text-search/encrypted-payload.json")
+            value = bson.encode({"v": "foo"})
+            encrypted = await encrypter.encrypt(
+                value,
+                "textPreview",
+                key_id=key_id,
+                query_type="suffixPreview",
+                contention_factor=0,
+                text_opts=text_opts,
+            )
+            self.assertEqual(encrypted, expected)
+
 
 class TestNeedKMSAzureCredentials(unittest.TestCase):
     maxDiff = None
@@ -1444,6 +1484,30 @@ class TestExplicitEncryption(unittest.TestCase):
                 is_expression=True,
             )
 
+    def test_text_query(self):
+        key_path = "keys/ABCDEFAB123498761234123456789012-local-document.json"
+        key_id = json_data(key_path)["_id"]
+        encrypter = ExplicitEncrypter(
+            MockCallback(
+                key_docs=[bson_data(key_path)], kms_reply=http_data("kms-reply.txt")
+            ),
+            self.mongo_crypt_opts(),
+        )
+        self.addCleanup(encrypter.close)
+
+        text_opts = bson_data("fle2-text-search/textopts.json")
+        expected = bson_data("fle2-text-search/encrypted-payload.json")
+        value = bson.encode({"v": "foo"})
+        encrypted = encrypter.encrypt(
+            value,
+            "textPreview",
+            key_id=key_id,
+            query_type="suffixPreview",
+            contention_factor=0,
+            text_opts=text_opts,
+        )
+        self.assertEqual(encrypted, expected)
+
 
 def read(filename, **kwargs):
     with open(os.path.join(DATA_DIR, filename), **kwargs) as fp:
