@@ -2,8 +2,10 @@ description = """Prints the list of files in a compilation database.
 Run with python ./list-compile-files.py <path/to/compile_commands.json>
 """
 
+from fnmatch import fnmatch
 import sys
 import json
+import os
 
 if len(sys.argv) != 2:
     print(description)
@@ -11,5 +13,8 @@ if len(sys.argv) != 2:
 
 compile_db = json.load(open(sys.argv[1] + "compile_commands.json", "r"))
 for entry in compile_db:
-    print(entry["file"])
-print("")
\ No newline at end of file
+    fpath = entry['file']
+    fname = os.path.basename(fpath)
+    if fnmatch(fname, 'mc-*') or fnmatch(fname, 'mongocrypt-*'):
+        print(fpath)
+print("")
