@@ -43,6 +43,7 @@ kmip_writer_t *
 kmip_writer_new (void)
 {
    kmip_writer_t *writer = calloc (1, sizeof (kmip_writer_t));
+   KMS_ASSERT (writer);
    writer->buffer = kms_request_str_new ();
    return writer;
 }
@@ -178,6 +179,14 @@ kmip_writer_write_enumeration (kmip_writer_t *writer, kmip_tag_type_t tag, int32
    kmip_writer_write_u32 (writer, 0);
 }
 
+void kmip_writer_write_bool (kmip_writer_t *writer, kmip_tag_type_t tag, bool value)
+{
+   kmip_writer_write_tag_enum (writer, tag);
+   kmip_writer_write_u8 (writer, KMIP_ITEM_TYPE_Boolean);
+   kmip_writer_write_u32 (writer, 8);
+   kmip_writer_write_u64(writer, (uint64_t) value);
+}
+
 void
 kmip_writer_write_datetime (kmip_writer_t *writer, kmip_tag_type_t tag, int64_t value)
 {
@@ -197,7 +206,7 @@ kmip_writer_begin_struct (kmip_writer_t *writer, kmip_tag_type_t tag)
    size_t pos = writer->buffer->len;
 
    kmip_writer_write_u32 (writer, 0);
-   KMS_ASSERT(writer->cur_pos < MAX_KMIP_WRITER_POSITIONS);
+   KMS_ASSERT(writer->cur_pos < MAX_KMIP_WRITER_POSITIONS - 1);
    writer->cur_pos++;
    writer->positions[writer->cur_pos] = pos;
 }
@@ -233,6 +242,7 @@ kmip_reader_t *
 kmip_reader_new (uint8_t *ptr, size_t len)
 {
    kmip_reader_t *reader = calloc (1, sizeof (kmip_reader_t));
+   KMS_ASSERT (reader);
    reader->ptr = ptr;
    reader->len = len;
    return reader;
@@ -271,7 +281,8 @@ kmip_reader_has_data (kmip_reader_t *reader)
 #define CHECK_REMAINING_BUFFER_AND_RET(read_size)   \
    if ((reader->pos + (read_size)) > reader->len) { \
       return false;                                 \
-   }
+   } else                                           \
+      ((void)0)
 
 bool
 kmip_reader_read_u8 (kmip_reader_t *reader, uint8_t *value)
@@ -338,7 +349,8 @@ kmip_reader_read_bytes (kmip_reader_t *reader, uint8_t **ptr, size_t length)
 #define CHECK_AND_RET(x) \
    if (!(x)) {           \
       return false;      \
-   }
+   } else                \
+      ((void)0)
 
 bool
 kmip_reader_read_tag (kmip_reader_t *reader, kmip_tag_type_t *tag)
@@ -384,6 +396,15 @@ kmip_reader_read_enumeration (kmip_reader_t *reader, uint32_t *enum_value)
    return kmip_reader_read_u32 (reader, &ignored);
 }
 
+bool
+kmip_reader_read_bool (kmip_reader_t *reader, bool *value)
+{
+   uint64_t u64;
+   CHECK_AND_RET (kmip_reader_read_u64 (reader, &u64));
+   *value = (bool) u64;
+   return true;
+}
+
 bool
 kmip_reader_read_integer (kmip_reader_t *reader, int32_t *value)
 {
