@@ -18,13 +18,18 @@
 #define TEST_KMS_ONLINE_UTIL_H
 
 #include <mongoc/mongoc.h>
-#include <kms_message/kms_request.h>
-#include <kms_message/kms_response.h>
+#include "kms_message/kms_request.h"
+#include "kms_message/kms_response.h"
 
+/* connect_with_tls creates a TLS stream.
+ * port may be NULL. It defaults to "443".
+ * ssl_opt may be NULL. It defaults to mongoc_ssl_opt_default (). */
 mongoc_stream_t *
-connect_with_tls (const char *host);
+connect_with_tls (const char *host,
+                  const char *port,
+                  mongoc_ssl_opt_t *ssl_opt);
 
 kms_response_t *
 send_kms_request (kms_request_t *req, const char *host);
 
-#endif /* TEST_KMS_ONLINE_UTIL_H */
\ No newline at end of file
+#endif /* TEST_KMS_ONLINE_UTIL_H */
