@@ -34,11 +34,9 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
     _mongocrypt_buffer_copy_from_hex(&expect_keyId1, "12345678123498761234123456789012");
     _mongocrypt_buffer_copy_from_hex(&expect_keyId2, "abcdefab123498761234123456789012");
 
-    const bool use_range_v2 = false;
-
     {
         _load_test_file(tester, "./test/data/efc/efc-oneField.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, 0);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -50,7 +48,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-oneField-goodVersionSet.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, 1);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -62,7 +60,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-extraField.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, 0);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -74,7 +72,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-twoFields.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, 0);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -90,7 +88,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-missingKeyId.json", &efc_bson);
-        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2),
+        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status),
                             status,
                             "unable to find 'keyId' in 'field' document");
         mc_EncryptedFieldConfig_cleanup(&efc);
@@ -99,7 +97,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-oneField-badVersionSet.json", &efc_bson);
-        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2),
+        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status),
                             status,
                             "'strEncodeVersion' of 99 is not supported");
         mc_EncryptedFieldConfig_cleanup(&efc);
@@ -108,7 +106,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-textSearchFields.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, LATEST_STR_ENCODE_VERSION);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -126,7 +124,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-textSearchFields-goodVersionSet.json", &efc_bson);
-        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2), status);
+        ASSERT_OK_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status), status);
         ASSERT_CMPUINT8(efc.str_encode_version, ==, 1);
         ptr = efc.fields;
         ASSERT(ptr);
@@ -144,7 +142,7 @@ static void _test_efc(_mongocrypt_tester_t *tester) {
 
     {
         _load_test_file(tester, "./test/data/efc/efc-textSearchFields-badVersionSet.json", &efc_bson);
-        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status, use_range_v2),
+        ASSERT_FAILS_STATUS(mc_EncryptedFieldConfig_parse(&efc, &efc_bson, status),
                             status,
                             "'strEncodeVersion' of 99 is not supported");
         mc_EncryptedFieldConfig_cleanup(&efc);
