@@ -2,7 +2,7 @@
 
 #include "mongocrypt-dll-private.h"
 
-#include <mlib/path.h>
+#include <mc-mlib/path.h>
 
 #include "test-mongocrypt.h"
 
@@ -13,10 +13,13 @@ static void _test_load_simple_library(_mongocrypt_tester_t *t) {
     mstr dll_path =
         mpath_join(mpath_parent(self_path.view, MPATH_NATIVE), mstrv_view_cstr("test-dll.dll"), MPATH_NATIVE);
 
-    mcr_dll lib = mcr_dll_open(dll_path.data);
-    BSON_ASSERT(lib.error_string.len == 0);
+    mcr_dll lib = mcr_dll_open(dll_path.raw.data);
+    BSON_ASSERT(lib.error_string.raw.len == 0);
+
+    MC_BEGIN_CAST_FUNCTION_TYPE_STRICT_IGNORE
+    int (*say_hello)(void) = (int (*)(void))mcr_dll_sym(lib, "say_hello");
+    MC_END_CAST_FUNCTION_TYPE_STRICT_IGNORE
 
-    int (*say_hello)(void) = mcr_dll_sym(lib, "say_hello");
     BSON_ASSERT(say_hello != NULL);
 
     int rval = say_hello();
@@ -31,7 +34,7 @@ static void _test_load_nonesuch(_mongocrypt_tester_t *t) {
     (void)t;
     mcr_dll lib = mcr_dll_open("no-such-directory/no-such-lib.dll");
     BSON_ASSERT(lib._native_handle == NULL);
-    BSON_ASSERT(lib.error_string.len > 0);
+    BSON_ASSERT(lib.error_string.raw.len > 0);
     mcr_dll_close(lib);
 }
 
